@@ -464,7 +464,8 @@ class RedisRoot:
                 django_field_name = django_field.name
                 allowed = True
                 if exclude_fields:
-                    allowed = (django_field.name in exclude_fields)
+                    allowed = (django_field.name not in exclude_fields)
+                    print(allowed, django_field.name)
                 if allowed:
                     if django_field.name in ['id', 'pk']:
                         django_field_name = 'django_id'
